import matplotlib.pyplot as plt
import pandas as pd
import numpy as np


def plot_episode_stats(stats, smoothing_window=10, noshow=False):
    fig, axes = plt.subplots(1, 2, figsize=(10, 5), tight_layout=True)

    # Plot the episode length over time
    ax = axes[0]
    ax.plot(stats.episode_lengths)
    ax.set_xlabel("Episode")
    ax.set_ylabel("Episode Length")
    ax.set_title("Episode Length over Time")

    # Plot the episode reward over time
    ax = axes[1]
    rewards_smoothed = pd.Series(stats.episode_rewards).rolling(smoothing_window, min_periods=smoothing_window).mean()
    ax.plot(rewards_smoothed)
    ax.set_xlabel("Episode")
    ax.set_ylabel("Episode Reward (Smoothed)")
    ax.set_title("Episode Reward over Time\n(Smoothed over window size {})".format(smoothing_window))

    
def plot_cliff_q(Q):
    max_q_values = np.full((4, 12), -np.inf)
    
    for idx, values in Q.items():
    
        max_q_values[np.unravel_index(idx, (4, 12))] = values.max()
        
    for row in max_q_values:
        print("\t".join(["{:.2f}".format(v) for v in row]))
    